@@ -304,6 +304,25 @@ class Loaf:
             raise Exception("No table specified.")
         self.query(f"DELETE FROM {table} WHERE {where}")
 
+    # A quick UPDATE query.
+    def update(self, table, columns, values, where=""):
+        # First fabricate the query string.
+        if type(columns) != type(values):
+            raise Exception("The COLUMNS and VALUES arguments must be of the same type.")
+        if type(columns) == str:
+            finalColumns = columns
+            finalValues = parse(values)
+        elif type(columns) == list:
+            if len(columns) != len(values):
+                raise Exception("The COLUMNS and VALUES arguments must be the same length.")
+            setValues = ""
+            for i in range(len(columns)):
+                setValues += f"{columns[i]} = {parse(values[i])}, "
+            setValues = finalColumns[:-2]
+        else:
+            raise Exception("Invalid COLUMNS or VALUES type.")
+        self.query(f"UPDATE {table} SET {setValues} WHERE {where}")
+
     # Get all values from a table.
     def all(self, table):
         # Sanity check.
